local VERSION = tonumber(("$Revision: 31165 $"):match("%d+"))

local QuestsFu = QuestsFu
local QuestsFu_PartyNotify = QuestsFu:NewModule("PartyNotify", "AceEvent-2.0", "AceConsole-2.0")
if QuestsFu.revision < VERSION then
	QuestsFu.version = "r" .. VERSION
	QuestsFu.revision = VERSION
	QuestsFu.date = ("$Date: 2007-03-28 01:51:48 -0400 (Wed, 28 Mar 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local L = AceLibrary("AceLocale-2.2"):new("QuestsFu_PartyNotify")
L:RegisterTranslations("enUS", function() return {
	["Party notifications"] = true,
	["Notify when party members advance their quests"] = true,
	["Messageframe"] = true,
	["Show in the messageframe (like normal quest notifications)"] = true,
	["Chat"] = true,
	["Show in the chatframe"] = true,
	["completed"] = true,
} end)

function QuestsFu_PartyNotify:OnInitialize()
	self.db = QuestsFu:AcquireDBNamespace("PartyNotify")
	QuestsFu:RegisterDefaults("PartyNotify", "profile", {
		message = true,
		chat = false,
	})
	QuestsFu.options.args.PartyNotify = {
		name = L["Party notifications"],
		desc = L["Notify when party members advance their quests"],
		type = "group",
		args = {
			message = {
				type = "toggle", name = L["Messageframe"],
				desc = L["Show in the messageframe (like normal quest notifications)"],
				get = function() return self.db.profile.message end,
				set = function(t) self.db.profile.message = t end,
			},
			chat = {
				type = "toggle", name = L["Chat"],
				desc = L["Show in the chatframe"],
				get = function() return self.db.profile.chat end,
				set = function(t) self.db.profile.chat = t end,
			},
			toggle = {
				name = AceLibrary("AceLocale-2.2"):new("QuestsFu")["Enabled"],
				desc = AceLibrary("AceLocale-2.2"):new("QuestsFu")["Suspend/resume this module."],
				type = 'toggle',
				order = -1,
				get = function() return QuestsFu:IsModuleActive(self) end,
				set = function() QuestsFu:ToggleModuleActive(self) end
			},
		},
	}
end

function QuestsFu_PartyNotify:OnEnable()
	self:RegisterEvent("Quixote_Party_Leaderboard_Update")
end

function QuestsFu_PartyNotify:Quixote_Party_Leaderboard_Update(sender, title, description, numHad, numGot, numNeeded)
	local message
	if numGot == numNeeded then
		message = ("(%s:%s) %s"):format(sender,title,L["completed"])
	else
		message = ("(%s:%s) %s: %d/%d"):format(sender,title,description,numGot,numNeeded)
	end
	if self.db.profile.message then
		UIErrorsFrame:AddMessage(message, 1.0, 1.0, 0.0, 1.0)
	end
	if self.db.profile.chat then
		self:Print(message)
	end
end
